<!--
Copyright (C) 2023 Maxwell G <maxwell@gtmx.me
SPDX-License-Identifier: MIT
-->

# releaserr

[![builds.sr.ht status](https://builds.sr.ht/~gotmax23/releaserr/commits/main.svg)](https://builds.sr.ht/~gotmax23/releaserr/commits/main?)
[![PyPI - Version](https://img.shields.io/pypi/v/releaserr?logo=pypi&label=releaserr%20on%20PyPI&color=blue)](https://pypi.org/project/releaserr/)

Simple, purpose-built release manager for @gotmax23's projects

## Links

- [releaserr project hub](https://sr.ht/~gotmax23/releaserr)
- [releaserr git.sr.ht repo](https://git.sr.ht/~gotmax23/releaserr)
- [releaserr tracker](https://todo.sr.ht/~gotmax23/releaserr)
- [releaserr mailing list][archives] ([~gotmax/releaserr@lists.sr.ht][mailto])

[archives]: https://lists.sr.ht/~gotmax23/releaserr
[mailto]: mailto:~gotmax/releaserr@lists.sr.ht

## Contributing

See [CONTRIBUTING.md](https://git.sr.ht/~gotmax23/releaserr/tree/main/item/CONTRIBUTING.md).

## License

This repository is licensed under

    SPDX-License-Identifer: MIT AND Unlicense

In general:

- Code is licensed under `MIT`.
- Templates in `releaserr/new/data` are licensed under `UNLICENSE`.
